import os


class ModuleNotFoundException(Exception):
    def __init__(self, module_name):
        message = f"{module_name} was not found in cwd or main program path!"
        super().__init__(message)


class ModuleLoader:
    name = None
    path = None

    def __init__(self, module_name, resource_provider):
        self.name = module_name

        # Сначала пробуем найти модуль рядом с yaml-файлом
        path = f"{resource_provider.path_to_configuration}/{module_name}"
        if os.path.exists(path):
            self.path = path
            return

        # Если нету, тогда в файлах modules в самой директории
        path = f"{resource_provider.main_file_path}/modules/{module_name}"
        if os.path.exists(path):
            self.path = path
            return

        # В последнем случае, пробуем найти модуль локально (в cwd)
        path = f"{resource_provider.cwd}/{module_name}"
        if os.path.exists(path):
            self.path = path
            return

        raise ModuleNotFoundException(module_name)

    def get_subdirectory_list(self):
        subdirectory_list = []
        for datapiece in os.scandir(self.path):
            # We are only interested in folders.
            if datapiece.is_file():
                continue
            subdirectory_list.append(f"{self.path}/{datapiece.name}")
        return subdirectory_list
